@@ -17,8 +17,10 @@
 from mesonbuild import mesonmain
 import sys, os
 
-thisfile = __file__
-if not os.path.isabs(thisfile):
-    thisfile = os.path.normpath(os.path.join(os.getcwd(), thisfile))
+def main():
+    # Always resolve the command path so Ninja can find it for regen, tests, etc.
+    launcher = os.path.realpath(sys.argv[0])
+    return mesonmain.run(launcher, sys.argv[1:])
 
-sys.exit(mesonmain.run(thisfile, sys.argv[1:]))
+if __name__ == '__main__':
+    sys.exit(main())
